@@ -236,7 +236,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
     ]),
     entries: ::phf::Slice::Static(&[
         (".udo", &["Csound"]),
-        (".cs", &["C#", "Smalltalk"]),
+        (".cs", &["Smalltalk", "C#"]),
         (".cfm", &["ColdFusion"]),
         (".cproject", &["XML"]),
         (".dockerfile", &["Dockerfile"]),
@@ -246,7 +246,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".jsonc", &["JSON with Comments"]),
         (".cr", &["Crystal"]),
         (".rq", &["SPARQL"]),
-        (".fcgi", &["PHP", "Shell", "Ruby", "Perl", "Lua", "Python"]),
+        (".fcgi", &["Lua", "Ruby", "PHP", "Python", "Perl", "Shell"]),
         (".ipf", &["IGOR Pro"]),
         (".gn", &["GN"]),
         (".vh", &["SystemVerilog"]),
@@ -300,10 +300,10 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".plist", &["XML Property List", "OpenStep Property List"]),
         (".txl", &["TXL"]),
         (".tla", &["TLA"]),
-        (".pod", &["Pod 6", "Pod"]),
+        (".pod", &["Pod", "Pod 6"]),
         (".cp", &["Component Pascal", "C++"]),
         (".irclog", &["IRC log"]),
-        (".as", &["ActionScript", "AngelScript"]),
+        (".as", &["AngelScript", "ActionScript"]),
         (".zimpl", &["Zimpl"]),
         (".gbr", &["Gerber Image"]),
         (".ccp", &["COBOL"]),
@@ -312,7 +312,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".clj", &["Clojure"]),
         (".pasm", &["Parrot Assembly"]),
         (".parrot", &["Parrot"]),
-        (".2", &["Roff", "Roff Manpage"]),
+        (".2", &["Roff Manpage", "Roff"]),
         (".cljc", &["Clojure"]),
         (".json5", &["JSON5"]),
         (".txt", &["Text"]),
@@ -322,13 +322,13 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".vcl", &["VCL"]),
         (".las", &["Lasso"]),
         (".oz", &["Oz"]),
-        (".for", &["Fortran", "Forth", "Formatted"]),
+        (".for", &["Forth", "Formatted", "Fortran"]),
         (".php5", &["PHP"]),
         (".jake", &["JavaScript"]),
         (".c++", &["C++"]),
         (".meta", &["Unity3D Asset"]),
         (".gitignore", &["Ignore List"]),
-        (".6", &["Roff", "Roff Manpage"]),
+        (".6", &["Roff Manpage", "Roff"]),
         (".pub", &["Public Key"]),
         (".gsp", &["Groovy Server Pages"]),
         (".jsonnet", &["Jsonnet"]),
@@ -342,7 +342,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".asn", &["ASN.1"]),
         (".sublime-keymap", &["JSON with Comments"]),
         (".thy", &["Isabelle"]),
-        (".properties", &["Java Properties", "INI"]),
+        (".properties", &["INI", "Java Properties"]),
         (".xacro", &["XML"]),
         (".wlua", &["Lua"]),
         (".launch", &["XML"]),
@@ -359,8 +359,8 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".opa", &["Opa"]),
         (".unity", &["Unity3D Asset"]),
         (".mediawiki", &["MediaWiki"]),
-        (".j", &["Jasmin", "Objective-J"]),
-        (".gd", &["GAP", "GDScript"]),
+        (".j", &["Objective-J", "Jasmin"]),
+        (".gd", &["GDScript", "GAP"]),
         (".rbxs", &["Lua"]),
         (".erb.deface", &["HTML+ERB"]),
         (".regexp", &["Regular Expression"]),
@@ -379,8 +379,8 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".bdy", &["PLSQL"]),
         (".nlogo", &["NetLogo"]),
         (".st", &["Smalltalk", "HTML"]),
-        (".1in", &["Roff", "Roff Manpage"]),
-        (".cfg", &["INI", "HAProxy"]),
+        (".1in", &["Roff Manpage", "Roff"]),
+        (".cfg", &["HAProxy", "INI"]),
         (".conll", &["CoNLL-U"]),
         (".bmx", &["BlitzMax"]),
         (".lhs", &["Literate Haskell"]),
@@ -395,23 +395,23 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".js.erb", &["JavaScript+ERB"]),
         (".fea", &["OpenType Feature File"]),
         (".zs", &["ZenScript"]),
-        (".4", &["Roff", "Roff Manpage"]),
+        (".4", &["Roff Manpage", "Roff"]),
         (".csh", &["Tcsh"]),
         (".nu", &["Nu"]),
         (".db2", &["SQLPL"]),
         (".flf", &["FIGlet Font"]),
-        (".dsp", &["Microsoft Developer Studio Project", "Faust"]),
+        (".dsp", &["Faust", "Microsoft Developer Studio Project"]),
         (".hc", &["HolyC"]),
         (".rest", &["reStructuredText"]),
         (".kojo", &["Scala"]),
         (".cxx-objdump", &["Cpp-ObjDump"]),
         (".xc", &["XC"]),
-        (".spec", &["Ruby", "RPM Spec", "Python"]),
+        (".spec", &["Ruby", "Python", "RPM Spec"]),
         (".gmx", &["XML"]),
         (".self", &["Self"]),
         (".slim", &["Slim"]),
         (".apl", &["APL"]),
-        (".hh", &["C++", "Hack"]),
+        (".hh", &["Hack", "C++"]),
         (".gtpl", &["Groovy"]),
         (".lsl", &["LSL"]),
         (".blade", &["Blade"]),
@@ -423,37 +423,37 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".sublime-snippet", &["XML"]),
         (".fsi", &["F#"]),
         (".tfvars", &["HCL"]),
-        (".1m", &["Roff", "Roff Manpage"]),
+        (".1m", &["Roff Manpage", "Roff"]),
         (".csv", &["CSV"]),
-        (".gs", &["Genie", "GLSL", "JavaScript", "Gosu"]),
-        (".vba", &["Vim script", "VBA"]),
+        (".gs", &["Genie", "GLSL", "Gosu", "JavaScript"]),
+        (".vba", &["VBA", "Vim script"]),
         (".escript", &["Erlang"]),
         (".owl", &["Web Ontology Language"]),
         (".plt", &["Gnuplot"]),
         (".c-objdump", &["C-ObjDump"]),
         (".vsixmanifest", &["XML"]),
         (".xib", &["XML"]),
-        (".brd", &["KiCad Legacy Layout", "Eagle"]),
+        (".brd", &["Eagle", "KiCad Legacy Layout"]),
         (".ll", &["LLVM"]),
         (".8xp", &["TI Program"]),
-        (".fx", &["FLUX", "HLSL"]),
-        (".3", &["Roff", "Roff Manpage"]),
+        (".fx", &["HLSL", "FLUX"]),
+        (".3", &["Roff Manpage", "Roff"]),
         (".tmpreferences", &["XML Property List"]),
         (".minid", &["MiniD"]),
         (".jinja", &["HTML+Django"]),
         (".xojo_script", &["Xojo"]),
         (".fxh", &["HLSL"]),
         (".gypi", &["Python"]),
-        (".pm", &["Raku", "Perl", "X PixMap"]),
+        (".pm", &["Perl", "Raku", "X PixMap"]),
         (".ml4", &["OCaml"]),
-        (".cake", &["C#", "CoffeeScript"]),
+        (".cake", &["CoffeeScript", "C#"]),
         (".pod6", &["Pod 6"]),
         (".rd", &["R"]),
         (".4dm", &["4D"]),
         (".nim.cfg", &["Nim"]),
         (".reds", &["Red"]),
         (".mxt", &["Max"]),
-        (".pp", &["Pascal", "Puppet"]),
+        (".pp", &["Puppet", "Pascal"]),
         (".pyp", &["Python"]),
         (".mysql", &["SQL"]),
         (".cmd", &["Batchfile"]),
@@ -476,11 +476,11 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".fth", &["Forth"]),
         (".raw", &["Raw token data"]),
         (".tea", &["Tea"]),
-        (".man", &["Roff", "Roff Manpage"]),
+        (".man", &["Roff Manpage", "Roff"]),
         (".grt", &["Groovy"]),
         (".tmac", &["Roff"]),
         (".pyw", &["Python"]),
-        (".1x", &["Roff", "Roff Manpage"]),
+        (".1x", &["Roff Manpage", "Roff"]),
         (".ditaval", &["XML"]),
         (".pbt", &["PowerBuilder"]),
         (".sjs", &["JavaScript"]),
@@ -505,7 +505,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".ebnf", &["EBNF"]),
         (".webmanifest", &["JSON"]),
         (".lol", &["LOLCODE"]),
-        (".asy", &["LTspice Symbol", "Asymptote"]),
+        (".asy", &["Asymptote", "LTspice Symbol"]),
         (".jinja2", &["HTML+Django"]),
         (".do", &["Stata"]),
         (".axml", &["XML"]),
@@ -515,7 +515,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".go", &["Go"]),
         (".cpp-objdump", &["Cpp-ObjDump"]),
         (".xht", &["HTML"]),
-        (".re", &["C++", "Reason"]),
+        (".re", &["Reason", "C++"]),
         (".riot", &["Riot"]),
         (".zeek", &["Zeek"]),
         (".props", &["XML"]),
@@ -530,7 +530,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".liquid", &["Liquid"]),
         (".hb", &["Harbour"]),
         (".aw", &["PHP"]),
-        (".shader", &["GLSL", "ShaderLab"]),
+        (".shader", &["ShaderLab", "GLSL"]),
         (".decls", &["BlitzBasic"]),
         (".dtx", &["TeX"]),
         (".cps", &["Component Pascal"]),
@@ -540,7 +540,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".sublime-settings", &["JSON with Comments"]),
         (".lpr", &["Pascal"]),
         (".pl6", &["Raku"]),
-        (".3qt", &["Roff", "Roff Manpage"]),
+        (".3qt", &["Roff Manpage", "Roff"]),
         (".robot", &["RobotFramework"]),
         (".yaml", &["YAML"]),
         (".nawk", &["Awk"]),
@@ -564,7 +564,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".eb", &["Easybuild"]),
         (".vala", &["Vala"]),
         (".svh", &["SystemVerilog"]),
-        (".rno", &["Roff", "RUNOFF"]),
+        (".rno", &["RUNOFF", "Roff"]),
         (".rego", &["Open Policy Agent"]),
         (".eclxml", &["ECL"]),
         (".grxml", &["XML"]),
@@ -590,27 +590,27 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".hql", &["HiveQL"]),
         (".cppobjdump", &["Cpp-ObjDump"]),
         (".monkey2", &["Monkey"]),
-        (".7", &["Roff", "Roff Manpage"]),
+        (".7", &["Roff Manpage", "Roff"]),
         (".xtend", &["Xtend"]),
         (".tcl", &["Tcl"]),
         (".ssjs", &["JavaScript"]),
         (".textile", &["Textile"]),
         (".com", &["DIGITAL Command Language"]),
         (".c++-objdump", &["Cpp-ObjDump"]),
-        (".ml", &["Standard ML", "OCaml"]),
+        (".ml", &["OCaml", "Standard ML"]),
         (".syntax", &["YAML"]),
         (".pan", &["Pan"]),
         (".oxh", &["Ox"]),
         (".me", &["Roff"]),
         (".s", &["Motorola 68K Assembly", "Unix Assembly"]),
-        (".tst", &["GAP", "Scilab"]),
+        (".tst", &["Scilab", "GAP"]),
         (".gbo", &["Gerber Image"]),
         (".rviz", &["YAML"]),
         (".gko", &["Gerber Image"]),
         (".bbx", &["TeX"]),
         (".ijs", &["J"]),
         (".jisonlex", &["Jison Lex"]),
-        (".l", &["Common Lisp", "Roff", "Lex", "PicoLisp"]),
+        (".l", &["Common Lisp", "Lex", "PicoLisp", "Roff"]),
         (".rbbas", &["REALbasic"]),
         (".pkgproj", &["XML"]),
         (".scss", &["SCSS"]),
@@ -619,9 +619,9 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".plantuml", &["PlantUML"]),
         (".mcfunction", &["mcfunction"]),
         (".vhi", &["VHDL"]),
-        (".1", &["Roff", "Roff Manpage"]),
+        (".1", &["Roff Manpage", "Roff"]),
         (".befunge", &["Befunge"]),
-        (".fr", &["Frege", "Forth", "Text"]),
+        (".fr", &["Forth", "Text", "Frege"]),
         (".ccproj", &["XML"]),
         (".zone", &["DNS Zone"]),
         (".jsb", &["JavaScript"]),
@@ -629,7 +629,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".matah", &["Stata"]),
         (".sss", &["SugarSS"]),
         (".click", &["Click"]),
-        (".mm", &["Objective-C++", "XML"]),
+        (".mm", &["XML", "Objective-C++"]),
         (".depproj", &["XML"]),
         (".pks", &["PLSQL"]),
         (".es6", &["JavaScript"]),
@@ -640,14 +640,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".hqf", &["SQF"]),
         (".ne", &["Nearley"]),
         (".sublime_metrics", &["JSON with Comments"]),
-        (".5", &["Roff", "Roff Manpage"]),
+        (".5", &["Roff Manpage", "Roff"]),
         (".pic", &["Pic"]),
         (".pony", &["Pony"]),
         (".bones", &["JavaScript"]),
         (".ct", &["XML"]),
         (".pls", &["PLSQL"]),
         (".sass", &["Sass"]),
-        (".9", &["Roff", "Roff Manpage"]),
+        (".9", &["Roff Manpage", "Roff"]),
         (".csx", &["C#"]),
         (".zmpl", &["Zimpl"]),
         (".rdf", &["XML"]),
@@ -672,7 +672,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".prefab", &["Unity3D Asset"]),
         (".8xk", &["TI Program"]),
         (".xql", &["XQuery"]),
-        (".cgi", &["Shell", "Perl", "Python"]),
+        (".cgi", &["Python", "Perl", "Shell"]),
         (".odin", &["Odin", "Object Data Instance Notation"]),
         (".lean", &["Lean"]),
         (".osm", &["XML"]),
@@ -696,7 +696,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".gst", &["Gosu"]),
         (".jsm", &["JavaScript"]),
         (".angelscript", &["AngelScript"]),
-        (".cls", &["ObjectScript", "TeX", "Apex", "VBA", "OpenEdge ABL"]),
+        (".cls", &["TeX", "VBA", "Apex", "OpenEdge ABL", "ObjectScript"]),
         (".workbook", &["Markdown"]),
         (".csproj", &["XML"]),
         (".tcsh", &["Tcsh"]),
@@ -746,7 +746,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".hlsli", &["HLSL"]),
         (".wxs", &["XML"]),
         (".adml", &["XML"]),
-        (".yy", &["Yacc", "JSON"]),
+        (".yy", &["JSON", "Yacc"]),
         (".gi", &["GAP"]),
         (".bats", &["Shell"]),
         (".org", &["Org"]),
@@ -779,7 +779,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".lagda", &["Literate Agda"]),
         (".bash", &["Shell"]),
         (".tfstate.backup", &["JSON"]),
-        (".t", &["Raku", "Turing", "Terra", "Perl"]),
+        (".t", &["Turing", "Perl", "Raku", "Terra"]),
         (".tpb", &["PLSQL"]),
         (".ampl", &["AMPL"]),
         (".wdl", &["wdl"]),
@@ -822,7 +822,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".mq4", &["MQL4"]),
         (".php", &["PHP", "Hack"]),
         (".ahkl", &["AutoHotkey"]),
-        (".ms", &["MAXScript", "Roff", "Unix Assembly"]),
+        (".ms", &["MAXScript", "Unix Assembly", "Roff"]),
         (".epsi", &["PostScript"]),
         (".htm", &["HTML"]),
         (".nsh", &["NSIS"]),
@@ -876,7 +876,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".tex", &["TeX"]),
         (".erl", &["Erlang"]),
         (".glf", &["Glyph"]),
-        (".pro", &["IDL", "Prolog", "QMake", "Proguard", "INI"]),
+        (".pro", &["Prolog", "IDL", "INI", "Proguard", "QMake"]),
         (".mk", &["Makefile"]),
         (".mli", &["OCaml"]),
         (".cobol", &["COBOL"]),
@@ -888,14 +888,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".sed", &["sed"]),
         (".desktop", &["desktop"]),
         (".html.hl", &["HTML"]),
-        (".rs", &["Rust", "RenderScript"]),
+        (".rs", &["RenderScript", "Rust"]),
         (".scm", &["Scheme"]),
         (".pcbdoc", &["Altium Designer"]),
         (".spc", &["PLSQL"]),
         (".eex", &["HTML+EEX"]),
         (".php4", &["PHP"]),
         (".spin", &["Propeller Spin"]),
-        (".f", &["Fortran", "Filebench WML", "Forth"]),
+        (".f", &["Forth", "Fortran", "Filebench WML"]),
         (".cnc", &["G-code"]),
         (".mcmeta", &["JSON"]),
         (".smt", &["SMT"]),
@@ -915,7 +915,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".rake", &["Ruby"]),
         (".pyde", &["Python"]),
         (".dfm", &["Pascal"]),
-        (".cl", &["Common Lisp", "Cool", "OpenCL"]),
+        (".cl", &["Cool", "OpenCL", "Common Lisp"]),
         (".texinfo", &["Texinfo"]),
         (".eliom", &["OCaml"]),
         (".js", &["JavaScript"]),
@@ -935,7 +935,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".em", &["EmberScript"]),
         (".gco", &["G-code"]),
         (".jsproj", &["XML"]),
-        (".3in", &["Roff", "Roff Manpage"]),
+        (".3in", &["Roff Manpage", "Roff"]),
         (".psgi", &["Perl"]),
         (".yml", &["YAML"]),
         (".jl", &["Julia"]),
@@ -970,7 +970,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".jade", &["Pug"]),
         (".n", &["Roff", "Nemerle"]),
         (".apib", &["API Blueprint"]),
-        (".nl", &["NewLisp", "NL"]),
+        (".nl", &["NL", "NewLisp"]),
         (".hcl", &["HCL"]),
         (".adb", &["Ada"]),
         (".dpr", &["Pascal"]),
@@ -992,7 +992,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".asset", &["Unity3D Asset"]),
         (".hs-boot", &["Haskell"]),
         (".gpb", &["Gerber Image"]),
-        (".mod", &["Modula-2", "Linux Kernel Module", "AMPL", "XML"]),
+        (".mod", &["AMPL", "Modula-2", "XML", "Linux Kernel Module"]),
         (".mao", &["Mako"]),
         (".rex", &["REXX"]),
         (".jsp", &["Java Server Pages"]),
@@ -1028,7 +1028,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".agda", &["Agda"]),
         (".f08", &["Fortran"]),
         (".rktl", &["Racket"]),
-        (".3pm", &["Roff", "Roff Manpage"]),
+        (".3pm", &["Roff Manpage", "Roff"]),
         (".cl2", &["Clojure"]),
         (".shen", &["Shen"]),
         (".har", &["JSON"]),
@@ -1047,7 +1047,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".snip", &["Vim Snippet"]),
         (".f77", &["Fortran"]),
         (".sthlp", &["Stata"]),
-        (".fs", &["GLSL", "Forth", "Filterscript", "F#"]),
+        (".fs", &["Forth", "Filterscript", "GLSL", "F#"]),
         (".dm", &["DM"]),
         (".rb", &["Ruby"]),
         (".duby", &["Mirah"]),
@@ -1078,7 +1078,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".podspec", &["Ruby"]),
         (".4th", &["Forth"]),
         (".hx", &["Haxe"]),
-        (".8", &["Roff", "Roff Manpage"]),
+        (".8", &["Roff Manpage", "Roff"]),
         (".sls", &["SaltStack", "Scheme"]),
         (".sh.in", &["Shell"]),
         (".watchr", &["Ruby"]),
@@ -1091,13 +1091,13 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".vshader", &["GLSL"]),
         (".dylan", &["Dylan"]),
         (".lasso", &["Lasso"]),
-        (".3m", &["Roff", "Roff Manpage"]),
+        (".3m", &["Roff Manpage", "Roff"]),
         (".nse", &["Lua"]),
         (".fancypack", &["Fancy"]),
         (".kml", &["XML"]),
         (".pytb", &["Python traceback"]),
         (".ihlp", &["Stata"]),
-        (".3x", &["Roff", "Roff Manpage"]),
+        (".3x", &["Roff Manpage", "Roff"]),
         (".dotsettings", &["XML"]),
         (".xslt", &["XSLT"]),
         (".cuh", &["Cuda"]),
@@ -1128,7 +1128,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".less", &["Less"]),
         (".graphqls", &["GraphQL"]),
         (".sqf", &["SQF"]),
-        (".v", &["V", "Coq", "Verilog"]),
+        (".v", &["Coq", "Verilog", "V"]),
         (".mask", &["Unity3D Asset", "Mask"]),
         (".rexx", &["REXX"]),
         (".apacheconf", &["ApacheConf"]),
@@ -1136,7 +1136,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".blade.php", &["Blade"]),
         (".doh", &["Stata"]),
         (".ps", &["PostScript"]),
-        (".sql", &["TSQL", "PLSQL", "SQL", "PLpgSQL", "SQLPL"]),
+        (".sql", &["PLSQL", "TSQL", "PLpgSQL", "SQLPL", "SQL"]),
         (".txi", &["Texinfo"]),
         (".sma", &["Pawn"]),
         (".wisp", &["wisp"]),
@@ -1146,7 +1146,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".psc", &["Papyrus"]),
         (".ada", &["Ada"]),
         (".viw", &["SQL"]),
-        (".ts", &["XML", "TypeScript"]),
+        (".ts", &["TypeScript", "XML"]),
         (".objdump", &["ObjDump"]),
         (".mjs", &["JavaScript"]),
         (".vhw", &["VHDL"]),
@@ -1158,14 +1158,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".lsp", &["Common Lisp", "NewLisp"]),
         (".boo", &["Boo"]),
         (".sco", &["Csound Score"]),
-        (".inc", &["Motorola 68K Assembly", "SourcePawn", "HTML", "PHP", "NASL", "C++", "Assembly", "SQL", "Pawn", "Pascal", "POV-Ray SDL"]),
+        (".inc", &["PHP", "Motorola 68K Assembly", "SourcePawn", "Assembly", "POV-Ray SDL", "Pawn", "NASL", "SQL", "C++", "HTML", "Pascal"]),
         (".volt", &["Volt"]),
         (".yrl", &["Erlang"]),
-        (".asc", &["AsciiDoc", "Public Key", "AGS Script"]),
+        (".asc", &["Public Key", "AsciiDoc", "AGS Script"]),
         (".targets", &["XML"]),
         (".vw", &["PLSQL"]),
         (".geom", &["GLSL"]),
-        (".m", &["Limbo", "M", "MUF", "Objective-C", "MATLAB", "Mathematica", "Mercury"]),
+        (".m", &["M", "Mathematica", "Objective-C", "MATLAB", "Mercury", "Limbo", "MUF"]),
         (".yaml-tmlanguage", &["YAML"]),
         (".ahk", &["AutoHotkey"]),
         (".lslp", &["LSL"]),
@@ -1177,7 +1177,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".tab", &["SQL"]),
         (".y", &["Yacc"]),
         (".opal", &["Opal"]),
-        (".gml", &["Game Maker Language", "XML", "Gerber Image", "Graph Modeling Language"]),
+        (".gml", &["Graph Modeling Language", "XML", "Gerber Image", "Game Maker Language"]),
         (".njk", &["HTML+Django"]),
         (".yar", &["YARA"]),
         (".6pl", &["Raku"]),
@@ -1194,7 +1194,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".gp", &["Gnuplot"]),
         (".c", &["C"]),
         (".hlsl", &["HLSL"]),
-        (".sc", &["SuperCollider", "Scala"]),
+        (".sc", &["Scala", "SuperCollider"]),
         (".wxi", &["XML"]),
         (".lookml", &["LookML"]),
         (".al", &["Perl"]),
@@ -1224,7 +1224,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".zpl", &["Zimpl"]),
         (".ash", &["AGS Script"]),
         (".iml", &["XML"]),
-        (".mdoc", &["Roff", "Roff Manpage"]),
+        (".mdoc", &["Roff Manpage", "Roff"]),
         (".swift", &["Swift"]),
         (".pat", &["Max"]),
         (".mg", &["Modula-3"]),
@@ -1235,7 +1235,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".bb", &["BlitzBasic", "BitBake"]),
         (".nix", &["Nix"]),
         (".sublime-workspace", &["JSON with Comments"]),
-        (".3p", &["Roff", "Roff Manpage"]),
+        (".3p", &["Roff Manpage", "Roff"]),
         (".ads", &["Ada"]),
         (".golo", &["Golo"]),
         (".cql", &["SQL"]),
@@ -1254,7 +1254,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".chem", &["Pic"]),
         (".mll", &["OCaml"]),
         (".q", &["q", "HiveQL"]),
-        (".x", &["Logos", "RPC", "Linker Script", "DirectX 3D File"]),
+        (".x", &["DirectX 3D File", "RPC", "Logos", "Linker Script"]),
         (".cshtml", &["HTML+Razor"]),
         (".pt", &["XML"]),
         (".dats", &["ATS"]),
@@ -1269,14 +1269,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".xojo_window", &["Xojo"]),
         (".graphql", &["GraphQL"]),
         (".x3d", &["XML"]),
-        (".rpy", &["Ren\'Py", "Python"]),
+        (".rpy", &["Python", "Ren\'Py"]),
         (".r3", &["Rebol"]),
         (".jq", &["JSONiq"]),
-        (".tsx", &["TSX", "XML"]),
+        (".tsx", &["XML", "TSX"]),
         (".vstemplate", &["XML"]),
         (".plx", &["Perl"]),
         (".zcml", &["XML"]),
-        (".i", &["SWIG", "Motorola 68K Assembly", "Assembly"]),
+        (".i", &["Motorola 68K Assembly", "SWIG", "Assembly"]),
         (".gtl", &["Gerber Image"]),
         (".mly", &["OCaml"]),
         (".ronn", &["Markdown"]),
@@ -1291,7 +1291,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".haml", &["Haml"]),
         (".ly", &["LilyPond"]),
         (".abnf", &["ABNF"]),
-        (".ls", &["LoomScript", "LiveScript"]),
+        (".ls", &["LiveScript", "LoomScript"]),
         (".snippets", &["Vim Snippet"]),
         (".sbt", &["Scala"]),
         (".h++", &["C++"]),
@@ -1323,7 +1323,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".csd", &["Csound Document"]),
         (".reek", &["YAML"]),
         (".dpatch", &["Darcs Patch"]),
-        (".nb", &["Text", "Mathematica"]),
+        (".nb", &["Mathematica", "Text"]),
         (".pxi", &["Cython"]),
         (".patch", &["Diff"]),
         (".urs", &["UrWeb"]),
@@ -1341,11 +1341,11 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".mxml", &["XML"]),
         (".tmcommand", &["XML Property List"]),
         (".rbw", &["Ruby"]),
-        (".e", &["E", "Eiffel"]),
+        (".e", &["Eiffel", "E"]),
         (".glsl", &["GLSL"]),
         (".ebuild", &["Gentoo Ebuild"]),
         (".abap", &["ABAP"]),
-        (".pl", &["Raku", "Prolog", "Perl"]),
+        (".pl", &["Prolog", "Perl", "Raku"]),
         (".arpa", &["DNS Zone"]),
         (".pmod", &["Pike"]),
         (".prw", &["xBase"]),
@@ -1379,7 +1379,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".eq", &["EQ"]),
         (".smali", &["Smali"]),
         (".vht", &["VHDL"]),
-        (".sch", &["KiCad Schematic", "Scheme", "Eagle", "XML"]),
+        (".sch", &["Eagle", "XML", "Scheme", "KiCad Schematic"]),
         (".sh", &["Shell"]),
         (".kt", &["Kotlin"]),
         (".prisma", &["Prisma"]),
