@@ -132,7 +132,7 @@ static INTERPRETERS: phf::Map<&'static str, &[&str]> =
         ("gn", &["GN"]),
         ("pwsh", &["PowerShell"]),
         ("lsl", &["LSL"]),
-        ("lua", &["Terra", "Lua"]),
+        ("lua", &["Lua", "Terra"]),
         ("gawk", &["Awk"]),
         ("guile", &["Scheme"]),
         ("scala", &["Scala"]),
@@ -140,7 +140,7 @@ static INTERPRETERS: phf::Map<&'static str, &[&str]> =
         ("openrc-run", &["OpenRC runscript"]),
         ("elixir", &["Elixir"]),
         ("aplx", &["APL"]),
-        ("ocaml", &["OCaml", "Reason"]),
+        ("ocaml", &["Reason", "OCaml"]),
         ("lisp", &["Common Lisp"]),
         ("parrot", &["Parrot Internal Representation", "Parrot Assembly"]),
         ("pike", &["Pike"]),
